@@ -1,5 +1,5 @@
 package File::Slurper;
-$File::Slurper::VERSION = '0.005';
+$File::Slurper::VERSION = '0.006';
 use strict;
 use warnings;
 
@@ -53,6 +53,7 @@ sub read_text {
 	my $layer = _text_layers($encoding, $crlf);
 	return read_binary($filename) if $layer eq ':raw';
 
+	local $PerlIO::encoding::fallback = 1;
 	open my $fh, "<$layer", $filename or croak "Couldn't open $filename: $!";
 	return do { local $/; <$fh> };
 }
@@ -62,6 +63,7 @@ sub write_text {
 	$encoding ||= 'utf-8';
 	my $layer = _text_layers($encoding, $crlf);
 
+	local $PerlIO::encoding::fallback = 1;
 	open my $fh, ">$layer", $filename or croak "Couldn't open $filename: $!";
 	print $fh $_[1] or croak "Couldn't write to $filename: $!";
 	close $fh or croak "Couldn't write to $filename: $!";
@@ -77,6 +79,7 @@ sub read_lines {
 	$encoding ||= 'utf-8';
 	my $layer = _text_layers($encoding, $crlf);
 
+	local $PerlIO::encoding::fallback = 1;
 	open my $fh, "<$layer", $filename or croak "Couldn't open $filename: $!";
 	return <$fh> if $skip_chomp;
 	my @buf = <$fh>;
@@ -107,7 +110,7 @@ File::Slurper - A simple, sane and efficient module to slurp a file
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -116,8 +119,6 @@ version 0.005
 
 =head1 DESCRIPTION
 
-B<DISCLAIMER>: this module is experimental, and may still change in non-compatible ways.
-
 This module provides functions for fast and correct slurping and spewing. All functions are optionally exported.
 
 =head1 FUNCTIONS
@@ -146,21 +147,13 @@ Writes C<$content> to file C<$filename> as binary data.
 
 Open C<dirname> and return all entries except C<.> and C<..>.
 
-=head1 TODO
-
-=over 4
-
-=item * C<open_text>?
-
-=back
-
 =head1 RATIONALE
 
 This module tries to make it as easy as possible to read and write files correctly and fast. The most correct way of doing this is not always obvious (e.g. L<#83126|https://rt.cpan.org/Public/Bug/Display.html?id=83126>), and just as often the most obvious correct way is not the fastest correct way. This module hides away all such complications behind an easy intuitive interface.
 
 =head1 DEPENDENCIES
 
-This module has an optional dependency on PerlIO::utf8_strict. Installing this will make UTF-8 encoded IO significantly faster, but should not otherwise affect the operation of this module. This may change into a dependency on the related Unicode::UTF8 in the future.
+This module has an optional dependency on L<PerlIO::utf8_strict|PerlIO::utf8_strict>. Installing this will make UTF-8 encoded IO significantly faster, but should not otherwise affect the operation of this module. This may change into a dependency on the related Unicode::UTF8 in the future.
 
 =head1 SEE ALSO
 
@@ -168,7 +161,7 @@ This module has an optional dependency on PerlIO::utf8_strict. Installing this w
 
 =item * L<Path::Tiny|Path::Tiny>
 
-A minimalistic abstraction not only around IO but also paths.
+A minimalistic abstraction handling not only IO but also paths.
 
 =item * L<IO::All|IO::All>
 
@@ -176,6 +169,14 @@ An attempt to expose as many IO related features as possible via a single API.
 
 =back
 
+=head1 TODO
+
+=over 4
+
+=item * C<open_text>?
+
+=back
+
 =head1 AUTHOR
 
 Leon Timmermans <leont@cpan.org>
